@@ -1,5 +1,6 @@
 import numpy as np
 
+
 # linear normalization
 def linear_normalization(matrix, types):
     """
@@ -16,6 +17,10 @@ def linear_normalization(matrix, types):
     --------
         ndarray
             Normalized decision matrix
+
+    Examples
+    ----------
+    >>> nmatrix = linear_normalization(matrix, types)
     """
     x_norm = np.zeros(np.shape(matrix))
     x_norm[:, types == 1] = matrix[:, types == 1] / (np.amax(matrix[:, types == 1], axis = 0))
@@ -39,6 +44,10 @@ def minmax_normalization(matrix, types):
     --------
         ndarray
             Normalized decision matrix
+
+    Examples
+    ----------
+    >>> nmatrix = minmax_normalization(matrix, types)
     """
     x_norm = np.zeros((matrix.shape[0], matrix.shape[1]))
     x_norm[:, types == 1] = (matrix[:, types == 1] - np.amin(matrix[:, types == 1], axis = 0)
@@ -66,6 +75,10 @@ def max_normalization(matrix, types):
     --------
         ndarray
             Normalized decision matrix
+
+    Examples
+    ----------
+    >>> nmatrix = max_normalization(matrix, types)
     """
     maximes = np.amax(matrix, axis = 0)
     matrix = matrix / maximes
@@ -89,6 +102,10 @@ def sum_normalization(matrix, types):
     --------
         ndarray
             Normalized decision matrix
+
+    Examples
+    ----------
+    >>> nmatrix = sum_normalization(matrix, types)
     """
     x_norm = np.zeros((matrix.shape[0], matrix.shape[1]))
     x_norm[:, types == 1] = matrix[:, types == 1] / np.sum(matrix[:, types == 1], axis = 0)
@@ -113,6 +130,10 @@ def vector_normalization(matrix, types):
     --------
         ndarray
             Normalized decision matrix
+
+    Examples
+    -----------
+    >>> nmatrix = vector_normalization(matrix, types)
     """
     x_norm = np.zeros((matrix.shape[0], matrix.shape[1]))
     x_norm[:, types == 1] = matrix[:, types == 1] / (np.sum(matrix[:, types == 1] ** 2, axis = 0))**(0.5)
@@ -130,6 +151,10 @@ def multimoora_normalization(matrix):
     ------------
         matrix : ndarray
             Decision matrix with m alternatives in rows and n criteria in columns
+
+    Examples
+    -----------
+    >>> nmatrix = multimoora_normalization(matrix)
     """
     x_norm = matrix / ((np.sum(matrix ** 2, axis = 0))**(0.5))
     return x_norm
